@@ -5,7 +5,7 @@ from datetime import datetime
 import hashlib
 import pathlib
 import sqlite_utils
-from sqlite_utils.db import AlterError
+from sqlite_utils.db import AlterError, DescIndex
 import textwrap
 import io
 import itertools
@@ -266,7 +266,7 @@ def vacuum(path):
 @click.option("--no-vacuum", help="Don't run VACUUM", default=False, is_flag=True)
 @load_extension_option
 def optimize(path, tables, no_vacuum, load_extension):
-    """Optimize all FTS tables and then run VACUUM - should shrink the database file"""
+    """Optimize all full-text search tables and then run VACUUM - should shrink the database file"""
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
     if not tables:
@@ -287,7 +287,7 @@ def optimize(path, tables, no_vacuum, load_extension):
 @click.argument("tables", nargs=-1)
 @load_extension_option
 def rebuild_fts(path, tables, load_extension):
-    """Rebuild all or specific FTS tables"""
+    """Rebuild all or specific full-text search tables"""
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
     if not tables:
@@ -450,11 +450,21 @@ def index_foreign_keys(path, load_extension):
 )
 @load_extension_option
 def create_index(path, table, column, name, unique, if_not_exists, load_extension):
-    "Add an index to the specified table covering the specified columns"
+    """
+    Add an index to the specified table covering the specified columns.
+    Use "sqlite-utils create-index mydb -- -column" to specify descending
+    order for a column.
+    """
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
+    # Treat -prefix as descending for columns
+    columns = []
+    for col in column:
+        if col.startswith("-"):
+            col = DescIndex(col[1:])
+        columns.append(col)
     db[table].create_index(
-        column, index_name=name, unique=unique, if_not_exists=if_not_exists
+        columns, index_name=name, unique=unique, if_not_exists=if_not_exists
     )
 
 
@@ -479,7 +489,7 @@ def create_index(path, table, column, name, unique, if_not_exists, load_extensio
 def enable_fts(
     path, table, column, fts4, fts5, tokenize, create_triggers, load_extension
 ):
-    "Enable FTS for specific table and columns"
+    "Enable full-text search for specific table and columns"
     fts_version = "FTS5"
     if fts4 and fts5:
         click.echo("Can only use one of --fts4 or --fts5", err=True)
@@ -507,7 +517,7 @@ def enable_fts(
 @click.argument("column", nargs=-1, required=True)
 @load_extension_option
 def populate_fts(path, table, column, load_extension):
-    "Re-populate FTS for specific table and columns"
+    "Re-populate full-text search for specific table and columns"
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
     db[table].populate_fts(column)
@@ -522,7 +532,7 @@ def populate_fts(path, table, column, load_extension):
 @click.argument("table")
 @load_extension_option
 def disable_fts(path, table, load_extension):
-    "Disable FTS for specific table"
+    "Disable full-text search for specific table"
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
     db[table].disable_fts()
@@ -684,7 +694,7 @@ def insert_upsert_implementation(
         raise click.ClickException("Use just one of --nl, --csv or --tsv")
     if encoding and not (csv or tsv):
         raise click.ClickException("--encoding must be used with --csv or --tsv")
-    encoding = encoding or "utf-8"
+    encoding = encoding or "utf-8-sig"
     buffered = io.BufferedReader(json_file, buffer_size=4096)
     decoded = io.TextIOWrapper(buffered, encoding=encoding)
     if pk and len(pk) == 1:
@@ -732,9 +742,16 @@ def insert_upsert_implementation(
         extra_kwargs["upsert"] = upsert
     # Apply {"$base64": true, ...} decoding, if needed
     docs = (decode_base64_values(doc) for doc in docs)
-    db[table].insert_all(
-        docs, pk=pk, batch_size=batch_size, alter=alter, **extra_kwargs
-    )
+    try:
+        db[table].insert_all(
+            docs, pk=pk, batch_size=batch_size, alter=alter, **extra_kwargs
+        )
+    except sqlite3.OperationalError as e:
+        if e.args and "has no column named" in e.args[0]:
+            raise click.ClickException(
+                "{}\n\nTry using --alter to add additional columns".format(e.args[0])
+            )
+        raise
 
 
 @cli.command()
@@ -905,7 +922,17 @@ def upsert(
 def create_table(
     path, table, columns, pk, not_null, default, fk, ignore, replace, load_extension
 ):
-    "Add an index to the specified table covering the specified columns"
+    """
+    Add a table with the specified columns. Columns should be specified using
+    name, type pairs, for example:
+
+    \b
+    sqlite-utils create-table my.db people \\
+        id integer \\
+        name text \\
+        height float \\
+        photo blob --pk id
+    """
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
     if len(columns) % 2 == 1:
@@ -946,14 +973,15 @@ def create_table(
     required=True,
 )
 @click.argument("table")
+@click.option("--ignore", is_flag=True)
 @load_extension_option
-def drop_table(path, table, load_extension):
+def drop_table(path, table, ignore, load_extension):
     "Drop the specified table"
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
-    if table in db.table_names():
-        db[table].drop()
-    else:
+    try:
+        db[table].drop(ignore=ignore)
+    except sqlite3.OperationalError:
         raise click.ClickException('Table "{}" does not exist'.format(table))
 
 
@@ -1002,14 +1030,15 @@ def create_view(path, view, select, ignore, replace, load_extension):
     required=True,
 )
 @click.argument("view")
+@click.option("--ignore", is_flag=True)
 @load_extension_option
-def drop_view(path, view, load_extension):
+def drop_view(path, view, ignore, load_extension):
     "Drop the specified view"
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
-    if view in db.view_names():
-        db[view].drop()
-    else:
+    try:
+        db[view].drop(ignore=ignore)
+    except sqlite3.OperationalError:
         raise click.ClickException('View "{}" does not exist'.format(view))
 
 
@@ -1267,9 +1296,12 @@ def triggers(
 @click.argument("table")
 @click.option(
     "--type",
-    type=(str, str),
+    type=(
+        str,
+        click.Choice(["INTEGER", "TEXT", "FLOAT", "BLOB"], case_sensitive=False),
+    ),
     multiple=True,
-    help="Change column type to X",
+    help="Change column type to INTEGER, TEXT, FLOAT or BLOB",
 )
 @click.option("--drop", type=str, multiple=True, help="Drop this column")
 @click.option(
