@@ -144,6 +144,10 @@ class InvalidColumns(Exception):
     pass
 
 
+class DescIndex(str):
+    pass
+
+
 _COUNTS_TABLE_CREATE_SQL = """
 CREATE TABLE IF NOT EXISTS [{}](
    [table] TEXT PRIMARY KEY,
@@ -593,7 +597,7 @@ class Database:
         table_sql = {}
         for table, column, other_table, other_column in foreign_keys_to_create:
             old_sql = table_sql.get(table, self[table].schema)
-            extra_sql = ",\n   FOREIGN KEY({column}) REFERENCES {other_table}({other_column})\n".format(
+            extra_sql = ",\n   FOREIGN KEY([{column}]) REFERENCES [{other_table}]([{other_column}])\n".format(
                 column=column, other_table=other_table, other_column=other_column
             )
             # Stick that bit in at the very end just before the closing ')'
@@ -677,6 +681,34 @@ class Queryable:
         for row in cursor:
             yield dict(zip(columns, row))
 
+    def pks_and_rows_where(
+        self,
+        where=None,
+        where_args=None,
+        order_by=None,
+        limit=None,
+        offset=None,
+    ):
+        "Like .rows_where() but returns (pk, row) pairs - pk can be a single value or tuple"
+        column_names = [column.name for column in self.columns]
+        pks = [column.name for column in self.columns if column.is_pk]
+        if not pks:
+            column_names.insert(0, "rowid")
+            pks = ["rowid"]
+        select = ",".join("[{}]".format(column_name) for column_name in column_names)
+        for row in self.rows_where(
+            select=select,
+            where=where,
+            where_args=where_args,
+            order_by=order_by,
+            limit=limit,
+            offset=offset,
+        ):
+            row_pk = tuple(row[pk] for pk in pks)
+            if len(row_pk) == 1:
+                row_pk = row_pk[0]
+            yield row_pk, row
+
     @property
     def columns(self):
         if not self.exists():
@@ -1128,6 +1160,13 @@ class Table(Queryable):
             index_name = "idx_{}_{}".format(
                 self.name.replace(" ", "_"), "_".join(columns)
             )
+        columns_sql = []
+        for column in columns:
+            if isinstance(column, DescIndex):
+                fmt = "[{}] desc"
+            else:
+                fmt = "[{}]"
+            columns_sql.append(fmt.format(column))
         sql = (
             textwrap.dedent(
                 """
@@ -1139,7 +1178,7 @@ class Table(Queryable):
             .format(
                 index_name=index_name,
                 table_name=self.name,
-                columns=", ".join("[{}]".format(c) for c in columns),
+                columns=", ".join(columns_sql),
                 unique="UNIQUE " if unique else "",
                 if_not_exists="IF NOT EXISTS " if if_not_exists else "",
             )
@@ -1184,8 +1223,12 @@ class Table(Queryable):
             self.add_foreign_key(col_name, fk, fk_col)
         return self
 
-    def drop(self):
-        self.db.execute("DROP TABLE [{}]".format(self.name))
+    def drop(self, ignore=False):
+        try:
+            self.db.execute("DROP TABLE [{}]".format(self.name))
+        except sqlite3.OperationalError:
+            if not ignore:
+                raise
 
     def guess_foreign_table(self, column):
         column = column.lower()
@@ -2167,8 +2210,12 @@ class View(Queryable):
             self.name, ", ".join(c.name for c in self.columns)
         )
 
-    def drop(self):
-        self.db.execute("DROP VIEW [{}]".format(self.name))
+    def drop(self, ignore=False):
+        try:
+            self.db.execute("DROP VIEW [{}]".format(self.name))
+        except sqlite3.OperationalError:
+            if not ignore:
+                raise
 
     def enable_fts(self, *args, **kwargs):
         raise NotImplementedError(
@@ -2186,7 +2233,7 @@ def jsonify_if_needed(value):
     if isinstance(value, decimal.Decimal):
         return float(value)
     if isinstance(value, (dict, list, tuple)):
-        return json.dumps(value, default=repr)
+        return json.dumps(value, default=repr, ensure_ascii=False)
     elif isinstance(value, (datetime.time, datetime.date, datetime.datetime)):
         return value.isoformat()
     elif isinstance(value, uuid.UUID):
