@@ -1,11 +1,13 @@
 from sqlite_utils.db import (
     Index,
     Database,
+    DescIndex,
     ForeignKey,
     AlterError,
     NoObviousTable,
     ForeignKey,
     Table,
+    View,
 )
 from sqlite_utils.utils import sqlite3
 import collections
@@ -360,6 +362,21 @@ def test_add_foreign_key(fresh_db):
     ] == fresh_db["books"].foreign_keys
 
 
+def test_add_foreign_key_if_column_contains_space(fresh_db):
+    fresh_db["authors"].insert_all([{"id": 1, "name": "Sally"}], pk="id")
+    fresh_db["books"].insert_all(
+        [
+            {"title": "Hedgehogs of the world", "author id": 1},
+        ]
+    )
+    fresh_db["books"].add_foreign_key("author id", "authors", "id")
+    assert fresh_db["books"].foreign_keys == [
+        ForeignKey(
+            table="books", column="author id", other_table="authors", other_column="id"
+        )
+    ]
+
+
 def test_add_foreign_key_error_if_column_does_not_exist(fresh_db):
     fresh_db["books"].insert(
         {"id": 1, "title": "Hedgehogs of the world", "author_id": 1}
@@ -423,7 +440,7 @@ def test_add_column_foreign_key(fresh_db):
     fresh_db.create_table("breeds", {"name": str})
     fresh_db["dogs"].add_column("breed_id", fk="breeds")
     assert (
-        "CREATE TABLE [dogs] ( [name] TEXT , [breed_id] INTEGER, FOREIGN KEY(breed_id) REFERENCES breeds(rowid) )"
+        "CREATE TABLE [dogs] ( [name] TEXT , [breed_id] INTEGER, FOREIGN KEY([breed_id]) REFERENCES [breeds]([rowid]) )"
         == collapse_whitespace(fresh_db["dogs"].schema)
     )
     # And again with an explicit primary key column
@@ -431,8 +448,8 @@ def test_add_column_foreign_key(fresh_db):
     fresh_db["dogs"].add_column("subbreed_id", fk="subbreeds")
     assert (
         "CREATE TABLE [dogs] ( [name] TEXT , [breed_id] INTEGER, [subbreed_id] TEXT, "
-        "FOREIGN KEY(breed_id) REFERENCES breeds(rowid), "
-        "FOREIGN KEY(subbreed_id) REFERENCES subbreeds(primkey) )"
+        "FOREIGN KEY([breed_id]) REFERENCES [breeds]([rowid]), "
+        "FOREIGN KEY([subbreed_id]) REFERENCES [subbreeds]([primkey]) )"
         == collapse_whitespace(fresh_db["dogs"].schema)
     )
 
@@ -443,7 +460,7 @@ def test_add_foreign_key_guess_table(fresh_db):
     fresh_db["dogs"].add_column("breed_id", int)
     fresh_db["dogs"].add_foreign_key("breed_id")
     assert (
-        "CREATE TABLE [dogs] ( [name] TEXT , [breed_id] INTEGER, FOREIGN KEY(breed_id) REFERENCES breeds(id) )"
+        "CREATE TABLE [dogs] ( [name] TEXT , [breed_id] INTEGER, FOREIGN KEY([breed_id]) REFERENCES [breeds]([id]) )"
         == collapse_whitespace(fresh_db["dogs"].schema)
     )
 
@@ -723,6 +740,19 @@ def test_create_index_if_not_exists(fresh_db):
     dogs.create_index(["name"], if_not_exists=True)
 
 
+def test_create_index_desc(fresh_db):
+    dogs = fresh_db["dogs"]
+    dogs.insert({"name": "Cleo", "twitter": "cleopaws", "age": 3, "is good dog": True})
+    assert [] == dogs.indexes
+    dogs.create_index([DescIndex("age"), "name"])
+    sql = fresh_db.execute(
+        "select sql from sqlite_master where name='idx_dogs_age_name'"
+    ).fetchone()[0]
+    assert sql == (
+        "CREATE INDEX [idx_dogs_age_name]\n" "    ON [dogs] ([age] desc, [name])"
+    )
+
+
 @pytest.mark.parametrize(
     "data_structure",
     (
@@ -732,7 +762,7 @@ def test_create_index_if_not_exists(fresh_db):
         {"dictionary": {"nested": "complex"}},
         collections.OrderedDict(
             [
-                ("key1", {"nested": "complex"}),
+                ("key1", {"nested": ["cømplex"]}),
                 ("key2", "foo"),
             ]
         ),
@@ -746,6 +776,14 @@ def test_insert_dictionaries_and_lists_as_json(fresh_db, data_structure):
     assert data_structure == json.loads(row[1])
 
 
+def test_insert_list_nested_unicode(fresh_db):
+    fresh_db["test"].insert(
+        {"id": 1, "data": {"key1": {"nested": ["cømplex"]}}}, pk="id"
+    )
+    row = fresh_db.execute("select id, data from test").fetchone()
+    assert row[1] == '{"key1": {"nested": ["cømplex"]}}'
+
+
 def test_insert_uuid(fresh_db):
     uuid4 = uuid.uuid4()
     fresh_db["test"].insert({"uuid": uuid4})
@@ -929,6 +967,21 @@ def test_drop_view(fresh_db):
     assert [] == fresh_db.view_names()
 
 
+def test_drop_ignore(fresh_db):
+    with pytest.raises(sqlite3.OperationalError):
+        fresh_db["does_not_exist"].drop()
+    fresh_db["does_not_exist"].drop(ignore=True)
+    # Testing view is harder, we need to create it in order
+    # to get a View object, then drop it twice
+    fresh_db.create_view("foo_view", "select 1")
+    view = fresh_db["foo_view"]
+    assert isinstance(view, View)
+    view.drop()
+    with pytest.raises(sqlite3.OperationalError):
+        view.drop()
+    view.drop(ignore=True)
+
+
 def test_insert_all_empty_list(fresh_db):
     fresh_db["t"].insert({"foo": 1})
     assert 1 == fresh_db["t"].count
